#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-DVdmBGeRxlc7i1VzEIAnaj
key:                  text-zipper-0.13-DVdmBGeRxlc7i1VzEIAnaj
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  febaa7d16e4a2f74e010fba53d567a35
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-DVdmBGeRxlc7i1VzEIAnaj
depends:
    base-4.18.2.1 deepseq-1.4.8.1 text-2.0.2
    vector-0.13.2.0-CDuZD6JA02PF3ZzyJqHF4G

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

